@@ -15,7 +15,7 @@
 
 from mistral import exceptions as exc
 from mistral import expressions as expr
-from mistral.tests import base
+from mistral.tests.unit import base
 
 DATA = {
     "server": {
@@ -99,18 +99,36 @@ class YaqlEvaluatorTest(base.BaseTest):
         self._evaluator.validate('$.a1 * $.a2')
 
     def test_validate_failed(self):
-        self.assertRaises(exc.YaqlEvaluationException,
+        self.assertRaises(exc.YaqlGrammarException,
                           self._evaluator.validate,
                           '*')
 
-        self.assertRaises(exc.YaqlEvaluationException,
+        self.assertRaises(exc.YaqlGrammarException,
                           self._evaluator.validate,
                           [1, 2, 3])
 
-        self.assertRaises(exc.YaqlEvaluationException,
+        self.assertRaises(exc.YaqlGrammarException,
                           self._evaluator.validate,
                           {'a': 1})
 
+    def test_json_pp(self):
+        self.assertEqual('"3"', self._evaluator.evaluate('json_pp($)', '3'))
+        self.assertEqual('3', self._evaluator.evaluate('json_pp($)', 3))
+        self.assertEqual(
+            '[\n    1,\n    2\n]',
+            self._evaluator.evaluate('json_pp($)', [1, 2])
+        )
+        self.assertEqual(
+            '{\n    "a": "b"\n}',
+            self._evaluator.evaluate('json_pp($)', {'a': 'b'})
+        )
+        self.assertEqual(
+            '"Mistral\nis\nawesome"',
+            self._evaluator.evaluate(
+                'json_pp($)', '\n'.join(['Mistral', 'is', 'awesome'])
+            )
+        )
+
 
 class InlineYAQLEvaluatorTest(base.BaseTest):
     def setUp(self):
@@ -166,7 +184,7 @@ class InlineYAQLEvaluatorTest(base.BaseTest):
         self._evaluator.validate('The value is <% $.a1 %>.')
 
     def test_validate_failed(self):
-        self.assertRaises(exc.YaqlEvaluationException,
+        self.assertRaises(exc.YaqlGrammarException,
                           self._evaluator.validate,
                           'The value is <% * %>.')
 
